ConsentLayerUIConfig class

Constructors

ConsentLayerUIConfig({CmpPosition position = CmpPosition.fullScreen, CmpBackgroundStyle backgroundStyle = CmpBackgroundStyle.dimmed, double cornerRadius = 0.0, bool respectsSafeArea = true, bool allowsOrientationChanges = true, bool isCancelable = true, Color? navigationBarColor, Color? backgroundColor, double? backgroundOpacity, double? blurRadius, Size? customSize, CmpGravity customGravity = CmpGravity.center, bool darkMode = false})

Properties

allowsOrientationChanges bool
final
backgroundColor Color?
final
backgroundOpacity double?
final
backgroundStyle CmpBackgroundStyle
final
blurRadius double?
Android (API 31+): window background blur radius in logical pixels. Ignored on iOS.
final
cornerRadius double
final
customGravity CmpGravity
final
customSize Size?
final
darkMode bool
final
hashCode int
The hash code for this object.
no setterinherited
isCancelable bool
final
final
position CmpPosition
final
respectsSafeArea bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited